@@ -1,4 +1,6 @@
 package Proc::Launcher;
+use strict;
+use warnings;
 use Mouse;
 
 our $VERSION = '0.0.1';
@@ -17,7 +19,7 @@ Proc::Launcher - yet another forking process controller
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
