@@ -1,4 +1,6 @@
 package Proc::Launcher::Supervisor;
+use strict;
+use warnings;
 use Mouse;
 
 our $VERSION = '0.0.1';
@@ -25,7 +27,7 @@ Proc::Launcher::Supervisor - restart watched processes that have exited
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 DESCRIPTION
 
